@@ -26,7 +26,8 @@ class CoreImpl(deskbar.interfaces.Core):
         
         self._threadpool = ThreadPool(5)
         self._gconf = GconfStore.get_instance()
-        self._history = DeskbarHistory().get_instance()
+        self._history = DeskbarHistory.get_instance(self._gconf.get_max_history_items())
+        self._gconf.connect("max-history-items-changed", lambda s, num: self._history.set_max_history_items(num))
         
         self._setup_module_loader(modules_dir)
         self._setup_module_list()
@@ -102,9 +103,6 @@ class CoreImpl(deskbar.interfaces.Core):
     def get_proxy_port(self):
         return self._gconf.get_proxy_port()
     
-    def get_ui_name(self):
-        return self._gconf.get_ui_name()
-    
     def get_collapsed_cat(self):
         return self._gconf.get_collapsed_cat()
     
@@ -120,6 +118,15 @@ class CoreImpl(deskbar.interfaces.Core):
     def get_sidebar_width(self):
         return self._gconf.get_sidebar_width()
     
+    def get_resultsview_width(self):
+    	return self._gconf.get_resultsview_width()
+    
+    def get_hide_after_action(self):
+    	return self._gconf.get_hide_after_action()
+    
+    def get_max_history_items(self):
+    	return self._gconf.get_max_history_items()
+    
     def set_keybinding(self, binding):
         self._gconf.set_keybinding(binding)
         if not self._keybinder.bind(binding):
@@ -163,6 +170,15 @@ class CoreImpl(deskbar.interfaces.Core):
     def set_sidebar_width(self, width):
         self._gconf.set_sidebar_width(width)
     
+    def set_resultsview_width(self, width):
+    	self._gconf.set_resultsview_width(width)
+    
+    def set_hide_after_action(self, width):
+    	self._gconf.set_hide_after_action(width)
+    
+    def set_max_history_items(self, amount):
+    	self._gconf.set_max_history_items(amount)
+    
     def get_history(self):
         """
         Returns History object
@@ -201,17 +217,17 @@ class CoreImpl(deskbar.interfaces.Core):
         self._module_list.increase_bottom_enabled_path()
     
     def stop_queries(self):
-        self._threadpool.stop()
         self._stop_queries = True
+        self._threadpool.stop()
     
     def query(self, text):
-        if (len(text) >= self.get_min_chars()):
+        if (len(text) >= self.get_min_chars()):            
             if (self._start_query_id != 0):
                 gobject.source_remove(self._start_query_id)
             self._start_query_id = gobject.timeout_add( self.get_type_delay(), self.query_real, text )
+            self._stop_queries = False
             
     def query_real(self, text):
-        self._stop_queries = False
         self._last_query = text
         for modname in self.get_enabled_modules():
             mod = self._module_list.get_module_instance_from_name( modname )
